<?php

namespace App\Http\Controllers;
use App\Models\Ingreso;
use App\Models\Peso;
use Illuminate\Support\Facades\Auth;

use Illuminate\Http\Request;
use GuzzleHttp\Client;

class IngresoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    { 
        $this->middleware('permission:ver ingreso', ['only' => ['index','show','imprimir']]);
        $this->middleware('permission:create ingreso', ['only' => ['create', 'store']]);
        $this->middleware('permission:editar ingreso', ['only' => ['update','edit']]);
        $this->middleware('permission:eliminar ingreso', ['only' => ['destroy']]);
    }
    public function index()
    {
        $ingresos = Ingreso::orderBy('created_at','desc')->paginate(200);
        return view('ingresos.index', compact('ingresos'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create(Request $request)
    {
        $ingresos = Ingreso::all(); 
        $user = Auth::user();
        $search = $request->input('search', '');
    
        // Obtener todos los números de salida de ingresos existentes
        $nrosSalidaRegistrados = Ingreso::pluck('NroSalida')->map(function ($item) {
            return explode('/', trim($item)); // Divide cada NroSalida por '/'
        })->flatten()->unique()->toArray(); // Aplanar y obtener valores únicos
    
        // Obtener registros de Pesos con paginación, búsqueda y orden descendente, excluyendo los que ya están registrados
        $pesos = Peso::when($search, function ($query, $search) {
            return $query->where('NroSalida', 'like', "%{$search}%");
        })
        ->whereNotIn('NroSalida', $nrosSalidaRegistrados) // Excluir todos los números de salida ya registrados
        ->orderBy('NroSalida', 'desc')
        ->paginate(30);
    
        return view('ingresos.create', compact('ingresos', 'pesos', 'search', 'user'));
    }
    






    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        
        $request->validate([
            'codigo' => 'required|string|max:255',
            'fecha_ingreso' => 'required|date',
            'estado' => 'required|string',
            'ref_lote' => 'nullable|string|max:255',
            'identificador' => 'required|string|max:20',
            'nom_iden' => 'nullable|string|max:255',
            'peso_total' => 'nullable|numeric',
            'NroSalida' => 'nullable|string|max:255',
            'placa' => 'nullable|string|max:255',
            'procedencia' => 'nullable|string|max:255',
            'deposito' => 'nullable|string|max:255',
            'balanza' => 'nullable|string|max:255',
            'tolva' => 'nullable|string|max:255',
            'guia_transporte' => 'nullable|string|max:255',
            'guia_remision' => 'nullable|string|max:255',
            'muestreo' => 'nullable|string|max:255',
            'preparacion' => 'nullable|string|max:255',
            'req_analisis' => 'nullable|string|max:255',
            'descuento' => 'nullable|string|max:255',
            'fecha_salida' => 'nullable|string|max:255',
            'retiro' => 'nullable|string|max:255',
            'pesoexterno' => 'nullable|string|max:255',
            'lote' => 'required|integer|between:1,64', 
            'descripcion' => 'nullable|string|max:255',
            'fase' => 'nullable|string|max:255',
            'restante' => 'nullable|string|max:255',

        ]);

        // Crear un nuevo ingreso
        $ingreso = new Ingreso();
        $ingreso->codigo = $request->codigo;
        $ingreso->fecha_ingreso = $request->fecha_ingreso;
        $ingreso->estado = $request->estado;
        $ingreso->ref_lote = $request->ref_lote;
        $ingreso->identificador = $request->identificador;
        $ingreso->nom_iden = $request->nom_iden;
        $ingreso->peso_total = $request->peso_total;
        $ingreso->NroSalida = $request->NroSalida;
        $ingreso->placa = $request->placa;
        $ingreso->procedencia = $request->procedencia;
        $ingreso->deposito = $request->deposito;
        $ingreso->balanza = $request->balanza;
        $ingreso->tolva = $request->tolva;
        $ingreso->guia_transporte = $request->guia_transporte;
        $ingreso->guia_remision = $request->guia_remision;
        $ingreso->muestreo = $request->muestreo;
        $ingreso->preparacion = $request->preparacion;
        $ingreso->req_analisis = $request->req_analisis;
        $ingreso->descuento = $request->descuento;
        $ingreso->fecha_salida = $request->fecha_salida;
        $ingreso->retiro = $request->retiro;
        $ingreso->pesoexterno = $request->pesoexterno;
        $ingreso->lote = $request->lote;
        $ingreso->descripcion = $request->descripcion;
        $ingreso->fase = $request->fase;
        $ingreso->restante = $request->restante;
        $ingreso->usuario_id = auth()->id();
        // Guardar el ingreso en la base de datos
        $ingreso->save();
        
        // Redireccionar con un mensaje
        return redirect()->route('ingresos.index')->with('success', 'Ingreso guardado exitosamente.');
    }
    
    
    /**
     * Display the specified resource.
     */
    public function show($id)
{
    $ingreso = Ingreso::findOrFail($id);
    return view('ingresos.show', compact('ingreso'));
}

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $ingreso = Ingreso::findOrFail($id);
        return view('ingresos.edit', compact('ingreso'));
    }


    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
{
    // Validar la solicitud
    $request->validate([
        'codigo' => 'required|string|max:255',
        'fecha_ingreso' => 'required|date',
        'estado' => 'required|string',
        'ref_lote' => 'nullable|string|max:255',
        'identificador' => 'required|string|max:20',
        'nom_iden' => 'nullable|string|max:255',
        'peso_total' => 'nullable|numeric',
        'NroSalida' => 'nullable|string|max:255',
        'placa' => 'nullable|string|max:255',
        'procedencia' => 'nullable|string|max:255',
        'deposito' => 'nullable|string|max:255',
        'balanza' => 'nullable|string|max:255',
        'tolva' => 'nullable|string|max:255',
        'guia_transporte' => 'nullable|string|max:255',
        'guia_remision' => 'nullable|string|max:255',
        'muestreo' => 'nullable|string|max:255',
        'prepracion' => 'nullable|string|max:255',
        'req_analisis' => 'nullable|string|max:255',
        'descuento' => 'nullable|string|max:255',
        'fecha_salida' => 'nullable|string|max:255',
        'retiro' => 'nullable|string|max:255',
        'pesoexterno' => 'nullable|string|max:255',
        'lote' => 'required|integer|between:1,64', 
        'descripcion' => 'nullable|string|max:255',
        'fase' => 'nullable|string|max:255',
        'restante' => 'nullable|string|max:255',
    ]);

    // Buscar el ingreso existente
    $ingreso = Ingreso::findOrFail($id);

    // Actualizar los campos
    $ingreso->codigo = $request->codigo;
    $ingreso->fecha_ingreso = $request->fecha_ingreso;
    $ingreso->estado = $request->estado;
    $ingreso->ref_lote = $request->ref_lote;
    $ingreso->identificador = $request->identificador;
    $ingreso->nom_iden = $request->nom_iden;
    $ingreso->peso_total = $request->peso_total;
    $ingreso->NroSalida = $request->NroSalida;
    $ingreso->placa = $request->placa;
    $ingreso->procedencia = $request->procedencia;
    $ingreso->deposito = $request->deposito;
    $ingreso->balanza = $request->balanza;
    $ingreso->tolva = $request->tolva;
    $ingreso->guia_transporte = $request->guia_transporte;
    $ingreso->guia_remision = $request->guia_remision;
    $ingreso->muestreo = $request->muestreo;
    $ingreso->preparacion = $request->plumeado;
    $ingreso->req_analisis = $request->req_analisis;
    $ingreso->descuento = $request->descuento;
    $ingreso->fecha_salida = $request->fecha_salida;
    $ingreso->retiro = $request->retiro;
    $ingreso->pesoexterno = $request->lote;
    $ingreso->lote = $request->pesoexterno;
    $ingreso->descripcion = $request->descripcion;
    $ingreso->fase = $request->fase;
    $ingreso->restante = $request->restante;
    $ingreso->usuario_id = auth()->id(); // Opcional, si deseas mantener el mismo usuario

    // Guardar los cambios en la base de datos
    $ingreso->save();

    // Redireccionar con un mensaje
    return redirect()->route('ingresos.index')->with('success', 'Ingreso actualizado exitosamente.');
}


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        // Buscar el ingreso por su ID
        $ingreso = Ingreso::findOrFail($id);
    
        // Eliminar el ingreso
        $ingreso->delete();
    
        // Redireccionar con un mensaje
        return redirect()->route('ingresos.index')->with('success', 'Ingreso eliminado exitosamente.');
    }
    
    public function buscarDocumento(Request $request)
    {
        $documento = $request->input('documento');

        $token = env('APIS_TOKEN');

        // Configurar el cliente GuzzleHttp
        $client = new Client([
            'base_uri' => 'https://api.apis.net.pe',
            'verify' => false,
        ]);

        // Determinar si es DNI o RUC
        $apiEndpoint = strlen($documento) === 8 ? '/v2/reniec/dni' : '/v2/sunat/ruc';

        // Configurar los parámetros de la solicitud
        $parameters = [
            'http_errors' => false,
            'connect_timeout' => 5,
            'headers' => [
                'Authorization' => 'Bearer ' . $token,
                'Referer' => 'https://apis.net.pe/api-consulta-ruc',
                'User-Agent' => 'laravel/guzzle',
                'Accept' => 'application/json',
            ],
            'query' => ['numero' => $documento],
        ];

        // Realizar la solicitud a la API
        $response = $client->request('GET', $apiEndpoint, $parameters);

        // Obtener los datos de respuesta como un arreglo
        $responseData = json_decode($response->getBody()->getContents(), true);

        // Devolver la respuesta o realizar otras acciones según tus necesidades
        return response()->json($responseData);
    }
    public function searchPesos(Request $request)
{
    $query = $request->input('query');

    $pesos = Peso::where('NroSalida', 'LIKE', "%{$query}%")
                  ->orWhere('Neto', 'LIKE', "%{$query}%")
                  ->orWhere('Placa', 'LIKE', "%{$query}%")
                  ->get();

    return response()->json($pesos);
}
public function imprimir($id)
{
    $ingreso = Ingreso::findOrFail($id);
    return view('ingresos.print', compact('ingreso'));
}
public function lotizar()
{
    $ingresos = Ingreso::all(); // O filtrar según lo necesites
    return view('ingresos.lotizacion', compact('ingresos'));
}
}
