@extends('layouts.app')

@section('content')
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        {{ __('TODAS LAS OPERACIONES REGISTRADAS') }}
                        
                        <a class="btn btn-sm btn-secondary" href="{{ route('ingresos.create') }}">
                            {{ __('CREAR NUEVO INGRESOS') }}
                        </a>
                    </div>
                    <div class="card-body">
                        
                        <table class="table table-striped table-hover text-center mb-0">
                            @if (count($ingresos) > 0)
                            <thead>
                                <tr>
                                    <th scope="col">{{ __('ID') }}</th>
                                    <th scope="col">{{ __('CODIGO') }}</th>
                                    <th scope="col">{{ __('DNI / RUC') }}</th>
                                    <th scope="col">{{ __('DATOS') }}</th>
                                    <th scope="col">{{ __('FECHA') }}</th>
                                    <th scope="col">{{ __('REF.LOTE ') }}</th>
                                    <th scope="col">{{ __('PESO TOTAL') }}</th>
                                    <th scope="col">{{ __('CREADO POR') }}</th>
                                    <th scope="col">{{ __('ACCION') }}</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($ingresos as $ingreso)
                                <tr>
                                    <td scope="row">{{ $ingreso->id }}</td>
                                    <td scope="row">{{ $ingreso->codigo }}</td>
                                    <td scope="row">{{ $ingreso->identificador }}</td>
                                    <td scope="row">{{ $ingreso->nom_iden }}</td>
                                    <td scope="row">{{ $ingreso->fecha_ingreso }}</td>
                                    <td scope="row">{{ $ingreso->ref_lote }}</td>
                                    <td scope="row">{{ $ingreso->peso_total }}</td>
                                    <td scope="row">{{ $ingreso->user ? $ingreso->user->name : 'Desconocido' }}</td>

                                    <td> 
                                        <a href="{{ route('ingresos.show', $ingreso->id) }}" class="btn btn-secondary btn-sm">
                                            {{ __('VER') }}
                                        </a>
                                        <a href="{{ route('ingresos.edit', $ingreso->id) }}" class="btn btn-warning btn-sm">
                                            {{ __('EDITAR') }}
                                        </a>
                                        <form action="{{ route('ingresos.destroy', $ingreso->id) }}" method="POST" class="eliminar-liquidaciones" style="display:inline;">
                                            @csrf
                                            @method('DELETE')
                                            <button type="submit" class="btn btn-danger btn-sm">ELIMINAR</button>
                                        </form>
                                        <a class="btn btn-primary btn-sm" href="{{ route('ingresos.imprimir', $ingreso->id) }}">
                                            {{ __('IMPRIMIR') }}
                                        </a>
                                        <a href="{{ route('lotizacion') }}" class="btn" style="background-color: green; color: white; font-size: 0.8rem; padding: 0.25rem 0.5rem;">VER LOTIZACION</a>

                                    </td>
                                </tr>
                                @endforeach
                            </tbody>
                            @else
                                <tr>
                                    <td colspan="10" class="text-center text-muted">{{ __('No hay datos disponibles') }}</td>
                                </tr>
                            @endif
                        </table>
                        <nav aria-label="Page navigation example">
                            <ul class="pagination justify-content-end">
                                <li class="page-item {{ $ingresos->onFirstPage() ? 'disabled' : '' }}">
                                    <a class="page-link" href="{{ $ingresos->previousPageUrl() }}">{{ __('Anterior') }}</a>
                                </li>
                                @for ($i = 1; $i <= $ingresos->lastPage(); $i++)
                                    <li class="page-item {{ $ingresos->currentPage() == $i ? 'active' : '' }}">
                                        <a class="page-link" href="{{ $ingresos->url($i) }}">{{ $i }}</a>
                                    </li>
                                @endfor
                                <li class="page-item {{ $ingresos->hasMorePages() ? '' : 'disabled' }}">
                                    <a class="page-link" href="{{ $ingresos->nextPageUrl() }}">{{ __('Siguiente') }}</a>
                                </li>
                            </ul>
                        </nav>
                    </div>
                </div>
            </div>
        </div>
    </div>
    @push('js')
        <script>
            @if(session('eliminar-registro') == 'Registro eliminado con éxito.')
                Swal.fire('Registro', 'eliminado exitosamente.', 'success')
            @endif
            @if(session('crear-registro') == 'Registro creado con éxito.')
                Swal.fire('Registro', 'creado exitosamente.', 'success')
            @endif
            @if(session('editar-registro') == 'Registro actualizado con éxito.')
                Swal.fire('Registro', 'actualizado exitosamente.', 'success')
            @endif
        </script>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                document.querySelectorAll('.eliminar-liquidaciones').forEach(form => {
                    form.addEventListener('submit', function(e){
                        e.preventDefault();
                        Swal.fire({
                            title: '¿Eliminar Ingreso?',
                            icon: 'warning',
                            showCancelButton: true,
                            confirmButtonColor: '#3085d6',
                            cancelButtonColor: '#d33',
                            confirmButtonText: '¡Sí, continuar!',
                            cancelButtonText: 'Cancelar'
                        }).then((result) => {
                            if (result.isConfirmed) {
                                this.submit(); // Envía el formulario si se confirma
                            }
                        });
                    });
                });
            });
        </script>
    @endpush
@endsection
