@extends('layouts.app')

@section('content')
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        {{ __('TODAS LAS OPERACIONES REGISTRADAS') }}
                        <a class="btn btn-sm btn-secondary" href="{{ route('liquidaciones.create') }}">
                            {{ __('CREAR NUEVO LIQUIDACIONES') }}
                        </a>
                    </div>
                    <div class="card-body">
                        <!-- Formulario de búsqueda -->
                        <form method="GET" action="{{ route('liquidaciones.index') }}" class="mb-3">
                            <div class="input-group">
                                <input type="text" name="search" value="{{ request('search') }}" class="form-control" placeholder="Buscar por muestra, cliente, peso o lote">
                                <div class="input-group-append">
                                    <button class="btn btn-secondary" type="submit">{{ __('Buscar') }}</button>
                                </div>
                            </div>
                        </form>

                        <table class="table table-striped table-hover text-center mb-0">
                            @if (count($liquidaciones) > 0)
                                <thead>
                                    <tr>
                                        <th scope="col">{{ __('ID') }}</th>
                                        <th scope="col">{{ __('MUESTRA') }}</th>
                                        <th scope="col">{{ __('CLIENTE') }}</th>
                                        <th scope="col">{{ __('EMPRESA') }}</th>
                                        <th scope="col">{{ __('PESO') }}</th>
                                        <th scope="col">{{ __('LOTE') }}</th>
                                        <th scope="col">{{ __('ESTADO') }}</th>
                                        <th scope="col">{{ __('TOTAL') }}</th>
                                        <th scope="col">{{ __('CREADO POR') }}</th>
                                        <th scope="col">{{ __('CIERRE FINAL') }}</th>
                                        <th scope="col">{{ __('ACCIONES') }}</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($liquidaciones as $liquidacion)
                                    <tr>
                                        <td>{{ $liquidacion->id }}</td>
                                        <td>{{ $liquidacion->muestra->codigo }}</td>
                                        <td>{{ $liquidacion->cliente->datos_cliente }}</td>
                                        <td>{{ $liquidacion->cliente->razon_social }}</td>
                                        <td>{{ $liquidacion->peso }}</td>
                                        <td>{{ $liquidacion->lote }}</td>
                                        <td>{{ $liquidacion->estado }}</td>
                                        <td>{{ $liquidacion->total }}</td>
                                        <td>{{ $liquidacion->creator->name ?? 'N/A' }} ({{ $liquidacion->created_at->format('d/m/Y - H:i:s') }})</td>
                                        <td>{{ $liquidacion->lastEditor->name ?? 'N/A'}} ({{ $liquidacion->updated_at->format('d/m/Y - H:i:s') }})</td> 
                                       
                                        
                                        <td>
                                            <a href="{{ route('liquidaciones.show', $liquidacion->id) }}" class="btn btn-secondary btn-sm">{{ __('VER') }}</a>
                                            
                                            @if ($liquidacion->estado !== 'CIERRE' && $liquidacion->estado !== 'PROVISIONAL')
                                                <form action="{{ route('duplicate', $liquidacion->id) }}" method="POST" style="display:inline;">
                                                    @csrf
                                                    <button type="submit" class="btn btn-success btn-sm">{{ __('CIERRE') }}</button>
                                                </form>
                                            @endif
                                        
                                            <a href="{{ route('liquidaciones.edit', $liquidacion->id) }}" class="btn btn-warning btn-sm">{{ __('EDITAR') }}</a>
                                            <a href="{{ route('liquidaciones.print', $liquidacion->id) }}" class="btn btn-primary btn-sm">{{ __('IMPRIMIR') }}</a>
                                            <form action="{{ route('liquidaciones.destroy', $liquidacion->id) }}" method="POST" style="display:inline;">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-danger btn-sm">{{ __('ELIMINAR') }}</button>
                                            </form>
                                        </td>
                                    </tr>
                                    @endforeach
                                </tbody>
                            @else
                                <tr>
                                    <td colspan="10" class="text-center text-muted">{{ __('No hay datos disponibles') }}</td>
                                </tr>
                            @endif
                        </table>

                        <nav aria-label="Page navigation example">
                            <ul class="pagination justify-content-end">
                                <li class="page-item {{ $liquidaciones->onFirstPage() ? 'disabled' : '' }}">
                                    <a class="page-link" href="{{ $liquidaciones->previousPageUrl() }}">{{ __('Anterior') }}</a>
                                </li>
                                @for ($i = 1; $i <= $liquidaciones->lastPage(); $i++)
                                    <li class="page-item {{ $liquidaciones->currentPage() == $i ? 'active' : '' }}">
                                        <a class="page-link" href="{{ $liquidaciones->url($i) }}">{{ $i }}</a>
                                    </li>
                                @endfor
                                <li class="page-item {{ $liquidaciones->hasMorePages() ? '' : 'disabled' }}">
                                    <a class="page-link" href="{{ $liquidaciones->nextPageUrl() }}">{{ __('Siguiente') }}</a>
                                </li>
                            </ul>
                        </nav>
                    </div>
                </div>
            </div>
        </div>
    </div>
    @push('js')
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            document.querySelectorAll('form[id^="duplicate-form-"]').forEach(form => {
                form.addEventListener('submit', function(event) {
                    event.preventDefault();
                    
                    var button = this.querySelector('button[type="submit"]');
                    button.style.display = 'none';

                    var xhr = new XMLHttpRequest();
                    xhr.open('POST', this.action, true);
                    xhr.setRequestHeader('X-CSRF-TOKEN', this.querySelector('input[name="_token"]').value);
                    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                    
                    xhr.onload = function() {
                        if (xhr.status >= 200 && xhr.status < 300) {
                            var response = JSON.parse(xhr.responseText);
                            alert(response.success ? 'Registro duplicado exitosamente!' : 'Error: ' + response.error);
                        } else {
                            alert('Error en la solicitud: ' + xhr.statusText);
                        }
                        button.style.display = 'inline-block';
                    };
                    
                    xhr.send(new URLSearchParams(new FormData(this)).toString());
                });
            });
        });
    </script>
    @endpush

@endsection
